@@ -221,9 +221,9 @@ class Stream(BaseStream):
         stream
     max_retries : int
         Max number of times to retry connecting the stream
-    proxy : Optional[str]
+    proxy : str | None
         URL of the proxy to use when connecting to the stream
-    verify : Union[bool, str]
+    verify : bool | str
         Either a boolean, in which case it controls whether to verify the
         server’s TLS certificate, or a string, in which case it must be a path
         to a CA bundle to use.
@@ -234,7 +234,7 @@ class Stream(BaseStream):
         Whether there's currently a stream running
     session : :class:`requests.Session`
         Requests Session used to connect to the stream
-    thread : Optional[:class:`threading.Thread`]
+    thread : :class:`threading.Thread` | None
         Thread used to run the stream
     user_agent : str
         User agent used when connecting to the stream
@@ -267,13 +267,13 @@ class Stream(BaseStream):
 
         Parameters
         ----------
-        follow : Optional[List[Union[int, str]]]
+        follow : list[int | str] | None
             User IDs, indicating the users to return statuses for in the stream
-        track : Optional[List[str]]
+        track : list[str] | None
             Keywords to track
-        locations : Optional[List[float]]
+        locations : list[float] | None
             Specifies a set of bounding boxes to track
-        filter_level : Optional[str]
+        filter_level : str | None
             Setting this parameter to one of none, low, or medium will set the
             minimum value of the filter_level Tweet attribute required to be
             included in the stream. The default value is none, which includes
@@ -282,7 +282,7 @@ class Stream(BaseStream):
             When displaying a stream of Tweets to end users (dashboards or live
             feeds at a presentation or conference, for example) it is suggested
             that you set this value to medium.
-        languages : Optional[List[str]]
+        languages : list[str] | None
             Setting this parameter to a comma-separated list of `BCP 47`_
             language identifiers corresponding to any of the languages listed
             on Twitter’s `advanced search`_ page will only return Tweets that
@@ -301,7 +301,7 @@ class Stream(BaseStream):
 
         Returns
         -------
-        Optional[threading.Thread]
+        threading.Thread | None
             The thread if ``threaded`` is set to ``True``, else ``None``
 
         References
@@ -347,7 +347,7 @@ class Stream(BaseStream):
 
         Parameters
         ----------
-        languages : Optional[List[str]]
+        languages : list[str] | None
             Setting this parameter to a comma-separated list of `BCP 47`_
             language identifiers corresponding to any of the languages listed
             on Twitter’s `advanced search`_ page will only return Tweets that
@@ -361,7 +361,7 @@ class Stream(BaseStream):
 
         Returns
         -------
-        Optional[threading.Thread]
+        threading.Thread | None
             The thread if ``threaded`` is set to ``True``, else ``None``
 
         References
@@ -518,7 +518,7 @@ class StreamingClient(BaseClient, BaseStream):
     ----------
     bearer_token : str
         Twitter API Bearer Token
-    return_type : Type[Union[dict, requests.Response, Response]]
+    return_type : type[dict | requests.Response | Response]
         Type to return from requests to the API
     wait_on_rate_limit : bool
         Whether to wait when rate limit is reached
@@ -533,9 +533,9 @@ class StreamingClient(BaseClient, BaseStream):
         stream
     max_retries : int
         Max number of times to retry connecting the stream
-    proxy : Optional[str]
+    proxy : str | None
         URL of the proxy to use when connecting to the stream
-    verify : Union[bool, str]
+    verify : bool | str
         Either a boolean, in which case it controls whether to verify the
         server’s TLS certificate, or a string, in which case it must be a path
         to a CA bundle to use.
@@ -546,7 +546,7 @@ class StreamingClient(BaseClient, BaseStream):
         Whether there's currently a stream running
     session : :class:`requests.Session`
         Requests Session used to connect to the stream
-    thread : Optional[:class:`threading.Thread`]
+    thread : :class:`threading.Thread` | None
         Thread used to run the stream
     user_agent : str
         User agent used when connecting to the stream
@@ -598,7 +598,7 @@ class StreamingClient(BaseClient, BaseStream):
 
         Parameters
         ----------
-        add : Union[List[StreamRule], StreamRule]
+        add : list[StreamRule] | StreamRule
             Specifies the operation you want to perform on the rules.
         dry_run : bool
             Set to true to test a the syntax of your rule without submitting
@@ -607,7 +607,7 @@ class StreamingClient(BaseClient, BaseStream):
 
         Returns
         -------
-        Union[dict, requests.Response, Response]
+        dict | requests.Response | Response
 
         References
         ----------
@@ -634,7 +634,7 @@ class StreamingClient(BaseClient, BaseStream):
 
         Parameters
         ----------
-        ids : Union[int, str, List[Union[int, str, StreamRule]], StreamRule]
+        ids : int | str | list[int | str | StreamRule] | StreamRule
             Array of rule IDs, each one representing a rule already active in
             your stream. IDs must be submitted as strings.
         dry_run : bool
@@ -644,7 +644,7 @@ class StreamingClient(BaseClient, BaseStream):
 
         Returns
         -------
-        Union[dict, requests.Response, Response]
+        dict | requests.Response | Response
 
         References
         ----------
@@ -682,7 +682,7 @@ class StreamingClient(BaseClient, BaseStream):
 
         Parameters
         ----------
-        backfill_minutes : Optional[int]
+        backfill_minutes : int | None
             By passing this parameter, you can request up to five (5) minutes
             worth of streaming data that you might have missed during a
             disconnection to be delivered to you upon reconnection. The
@@ -699,24 +699,24 @@ class StreamingClient(BaseClient, BaseStream):
 
             This feature is currently only available to the Academic Research
             product track.
-        expansions : Union[List[str], str]
+        expansions : list[str] | str
             :ref:`expansions_parameter`
-        media_fields : Union[List[str], str]
+        media_fields : list[str] | str
             :ref:`media_fields_parameter`
-        place_fields : Union[List[str], str]
+        place_fields : list[str] | str
             :ref:`place_fields_parameter`
-        poll_fields : Union[List[str], str]
+        poll_fields : list[str] | str
             :ref:`poll_fields_parameter`
-        tweet_fields : Union[List[str], str]
+        tweet_fields : list[str] | str
             :ref:`tweet_fields_parameter`
-        user_fields : Union[List[str], str]
+        user_fields : list[str] | str
             :ref:`user_fields_parameter`
         threaded : bool
             Whether or not to use a thread to run the stream
 
         Returns
         -------
-        Optional[threading.Thread]
+        threading.Thread | None
             The thread if ``threaded`` is set to ``True``, else ``None``
 
         References
@@ -752,13 +752,13 @@ class StreamingClient(BaseClient, BaseStream):
 
         Parameters
         ----------
-        ids : Union[List[str], str]
+        ids : list[str] | str
             Comma-separated list of rule IDs. If omitted, all rules are
             returned.
 
         Returns
         -------
-        Union[dict, requests.Response, Response]
+        dict | requests.Response | Response
 
         References
         ----------
@@ -784,7 +784,7 @@ class StreamingClient(BaseClient, BaseStream):
 
         Parameters
         ----------
-        backfill_minutes : Optional[int]
+        backfill_minutes : int | None
             By passing this parameter, you can request up to five (5) minutes
             worth of streaming data that you might have missed during a
             disconnection to be delivered to you upon reconnection. The
@@ -801,24 +801,24 @@ class StreamingClient(BaseClient, BaseStream):
 
             This feature is currently only available to the Academic Research
             product track.
-        expansions : Union[List[str], str]
+        expansions : list[str] | str
             :ref:`expansions_parameter`
-        media_fields : Union[List[str], str]
+        media_fields : list[str] | str
             :ref:`media_fields_parameter`
-        place_fields : Union[List[str], str]
+        place_fields : list[str] | str
             :ref:`place_fields_parameter`
-        poll_fields : Union[List[str], str]
+        poll_fields : list[str] | str
             :ref:`poll_fields_parameter`
-        tweet_fields : Union[List[str], str]
+        tweet_fields : list[str] | str
             :ref:`tweet_fields_parameter`
-        user_fields : Union[List[str], str]
+        user_fields : list[str] | str
             :ref:`user_fields_parameter`
         threaded : bool
             Whether or not to use a thread to run the stream
 
         Returns
         -------
-        Optional[threading.Thread]
+        threading.Thread | None
             The thread if ``threaded`` is set to ``True``, else ``None``
 
         References
@@ -920,7 +920,7 @@ class StreamingClient(BaseClient, BaseStream):
         
         Parameters
         ----------
-        matching_rules : List[StreamRule]
+        matching_rules : list[StreamRule]
             The matching rules received
         """
         pass
@@ -943,7 +943,7 @@ class StreamRule(NamedTuple):
 
     Parameters
     ----------
-    value : Optional[str]
+    value : str | None
         The rule text. If you are using a `Standard Project`_ at the Basic
         `access level`_, you can use the basic set of `operators`_, can submit
         up to 25 concurrent rules, and can submit rules up to 512 characters
@@ -951,11 +951,11 @@ class StreamRule(NamedTuple):
         access level, you can use all available operators, can submit up to
         1,000 concurrent rules, and can submit rules up to 1,024 characters
         long.
-    tag : Optional[str]
+    tag : str | None
         The tag label. This is a free-form text you can use to identify the
         rules that matched a specific Tweet in the streaming response. Tags can
         be the same across rules.
-    id : Optional[str]
+    id : str | None
         Unique identifier of this rule. This is returned as a string.
 
 
